#!/bin/sh
# asvis.cgi: A CGI script to explore association rules visually.
# To install, configure at the top of this file and then place on
# a web server to be executed as a CGI program. Place the association
# rules (mined and then postprocessed with postpro_rules) in the
# file specified in "RULES" (see below).
#
# Ensure that proper permissions are set so that the CGI program can read 
# "RULES" and execute "SORT_BY_FIELD" and "RULES_TO_HTML" from the AsVis
# package as well as standard *nix tools like echo, grep, sed and awk from
# somewhere along the PATH.
#
# Copyright (c) 2005 Kimmo Kulovesi <kkuloves@cs.helsinki.fi>


# Configure here:
PATH=/usr/bin:/bin
RULES=./rules
SORT_BY_FIELD=./sort_by_field
RULES_TO_HTML=./rules_to_html
ASVIS_TITLE="Mutation associations"


# Here be dragons

if echo "$HTTP_ACCEPT" | grep 'application/xhtml+xml' >/dev/null; then
    echo -e "Content-Type: application/xhtml+xml;charset=utf-8\r\n"
else
    echo -e "Content-Type: text/html;charset=utf-8\r\n"
fi

query=$(echo "$QUERY_STRING" | sed 's/[^a-z0-9=-]/ /g')

num=$(echo "$query" | awk -F'num=' '{
    num = $2
    if (num ~ /^[0-9]/)
        printf("%d", num)
    else if (num ~ /all/)
        printf("all")
    else
        printf("100")
}')
col=$(echo "$query" | awk -F'col=' '{ 
    col = $2
    if (col ~ /^[cfslj]/)
        printf("%1.1s", col)
    else
        printf("c")
}')
pos=$(echo "$query" | awk -F'pos=' '{
    pos = $2
    if (pos >= -10 && pos <= 10)
        printf("%d", pos)
}')

export ASVIS_TITLE

"$SORT_BY_FIELD" "$col" "$pos" <"$RULES" 2>/dev/null \
    | "$RULES_TO_HTML" "$num" "$col" "$pos"
